@@ -280,7 +280,7 @@ struct AbstractFileSystem //THREAD-SAFETY: "const" member functions must model t
     //symlink handling: follow
     //already existing + no onDeleteTargetFile: undefined behavior! (e.g. fail/overwrite/auto-rename)
     //returns current attributes at the time of copy
-    static FileCopyResult copyFileTransactional(const AbstractPath& sourcePath, const StreamAttributes& attrSource, //throw FileError, ErrorFileLocked, X
+    static FileCopyResult copyFileTransactional(const AbstractPath& sourcePath, const StreamAttributes& sourceAttr, //throw FileError, ErrorFileLocked, X
                                                 const AbstractPath& targetPath,
                                                 bool copyFilePermissions,
                                                 bool transactionalCopy,
@@ -345,7 +345,7 @@ protected:
                         const std::function<void(const SymlinkInfo& si)>& onSymlink) const; //
 
     //already existing: undefined behavior! (e.g. fail/overwrite/auto-rename)
-    FileCopyResult copyFileAsStream(const AfsPath& sourcePath, const StreamAttributes& attrSource, //throw FileError, ErrorFileLocked, X
+    FileCopyResult copyFileAsStream(const AfsPath& sourcePath, const StreamAttributes& sourceAttr, //throw FileError, ErrorFileLocked, X
                                     const AbstractPath& targetPath, const zen::IoCallback& notifyUnbufferedIO /*throw X*/) const;
 
 
@@ -412,7 +412,7 @@ private:
 
     //symlink handling: follow
     //already existing: undefined behavior! (e.g. fail/overwrite/auto-rename)
-    virtual FileCopyResult copyFileForSameAfsType(const AfsPath& sourcePath, const StreamAttributes& attrSource, //throw FileError, ErrorFileLocked, X
+    virtual FileCopyResult copyFileForSameAfsType(const AfsPath& sourcePath, const StreamAttributes& sourceAttr, //throw FileError, ErrorFileLocked, X
                                                   const AbstractPath& targetPath, bool copyFilePermissions,
                                                   //accummulated delta != file size! consider ADS, sparse, compressed files
                                                   const zen::IoCallback& notifyUnbufferedIO /*throw X*/) const = 0;
