@@ -78,7 +78,7 @@ FolderStatus getFolderStatusParallel(const std::set<AbstractPath>& folderPaths,
                 return futPassword.get(); //throw std::future_error -> if std::promise<Zstring> destroyed before password was set
             };
 
-            futAuth = runAsync([device /*clang bug*/= device, threadRequestPassword]
+            futAuth = runAsync([device, threadRequestPassword]
             {
                 setCurrentThreadName(Zstr("Auth: ") + utfTo<Zstring>(AFS::getDisplayPath(AbstractPath(device, AfsPath()))));
                 AFS::authenticateAccess(device, threadRequestPassword); //throw FileError, std::future_error
