@@ -36,17 +36,17 @@ Zstring getDotExtension(const Zstring& filePath) //including "." if extension is
 //or       "Sample 2012-05-15 131513"
 std::pair<time_t, Zstring> fff::impl::parseVersionedFileName(const Zstring& fileName)
 {
-    const auto ext = makeStringView(findLast(fileName.begin(), fileName.end(), Zstr('.')), fileName.end());
+    const ZstringView ext(findLast(fileName.begin(), fileName.end(), Zstr('.')), fileName.end());
 
     if (fileName.size() < 2 * ext.length() + 18)
         return {};
 
     const auto itExt1 = fileName.end() - (2 * ext.length() + 18);
-    if (!equalString(ext, makeStringView(itExt1, ext.length())))
+    if (!equalString(ext, ZstringView(itExt1, ext.length())))
         return {};
 
     const auto itTs   = itExt1 + ext.length();
-    const TimeComp tc = parseTime(Zstr(" %Y-%m-%d %H%M%S"), makeStringView(itTs, 18)); //returns TimeComp() on error
+    const TimeComp tc = parseTime(Zstr(" %Y-%m-%d %H%M%S"), ZstringView(itTs, 18)); //returns TimeComp() on error
 
     const auto [localTime, timeValid] = localToTimeT(tc);
     if (!timeValid)
@@ -91,7 +91,6 @@ AbstractPath FileVersioner::generateVersionedPath(const Zstring& relativePath) c
             versionedRelPath = relativePath + Zstr(' ') + timeStamp_ + getDotExtension(relativePath);
             assert(impl::parseVersionedFileName(getItemName(versionedRelPath)) ==
                    std::pair(syncStartTime_, getItemName(relativePath)));
-            (void)syncStartTime_; //clang: -Wunused-private-field
             break;
     }
     return AFS::appendRelPath(versioningFolderPath_, versionedRelPath);
@@ -560,8 +559,7 @@ void fff::applyVersioningLimit(const std::set<VersioningLimitFolder>& folderLimi
     const std::wstring txtRemoving = _("Removing old file versions:") + L' ';
     const std::wstring txtDeletingFolder = _("Deleting folder %x");
 
-    std::function<void(const AbstractPath& folderPath, AsyncCallback& acb)> deleteEmptyFolderTask;
-    deleteEmptyFolderTask = [&txtDeletingFolder, &protFolderItemCount, &deleteEmptyFolderTask](const AbstractPath& folderPath, AsyncCallback& acb) //throw ThreadStopRequest
+    auto deleteEmptyFolderTask = [&txtDeletingFolder, &protFolderItemCount](this const auto& self, const AbstractPath& folderPath, AsyncCallback& acb) -> void //throw ThreadStopRequest
     {
         const std::wstring errMsg = tryReportingError([&] //throw ThreadStopRequest
         {
@@ -575,7 +573,7 @@ void fff::applyVersioningLimit(const std::set<VersioningLimitFolder>& folderLimi
                 bool deleteParent = false;
                 protFolderItemCount.access([&](auto& folderItemCount2) { deleteParent = --folderItemCount2[*parentPath] == 0; });
                 if (deleteParent) //we're done here anyway => no need to schedule parent deletion in a separate task!
-                    deleteEmptyFolderTask(*parentPath, acb); //throw ThreadStopRequest
+                    self(*parentPath, acb); //throw ThreadStopRequest
             }
     };
 
@@ -589,7 +587,7 @@ void fff::applyVersioningLimit(const std::set<VersioningLimitFolder>& folderLimi
         });
 
     for (const auto& [itemPath, isSymlink] : itemsToDelete)
-        parallelWorkload.emplace_back(itemPath, [isSymlink /*clang bug*/= isSymlink, &txtRemoving, &protFolderItemCount, &deleteEmptyFolderTask](ParallelContext& ctx) //throw ThreadStopRequest
+        parallelWorkload.emplace_back(itemPath, [isSymlink, &txtRemoving, &protFolderItemCount, &deleteEmptyFolderTask](ParallelContext& ctx) //throw ThreadStopRequest
     {
         const std::wstring errMsg = tryReportingError([&] //throw ThreadStopRequest
         {
