@@ -26,6 +26,34 @@ const int EMAIL_SHORT_ITEMS_MAX   = 0; //
 const int SEPARATION_LINE_LEN = 40;
 
 
+std::wstring getUserDescription() //throw FileError
+{
+    const Zstring userName = getLoginUser(); //throw FileError
+    const Zstring hostName = getHostName(); //throw FileError
+
+    if (contains(getUpperCase(hostName), getUpperCase(userName)))
+        return utfTo<std::wstring>(userName); //no need for text duplication! e.g. "Zenju @ Zenju-PC"
+
+    return utfTo<std::wstring>(userName + Zstr(" @ ") + hostName); //e.g. "Admin @ Zenju-PC"
+}
+
+
+std::wstring /*may be empty*/ getMachineDescription() //throw FileError
+{
+    const ComputerModel cm = getComputerModel(); //throw FileError
+
+    std::wstring descr = cm.model;
+
+    if (!cm.vendor.empty())
+    {
+        if (!cm.model.empty())
+            descr += L' ';
+        descr += L'(' + cm.vendor + L')';
+    }
+    return descr;
+}
+
+
 std::string generateLogHeaderTxt(const ProcessSummary& s, const ErrorLog& log, int logPreviewMax)
 {
     const auto tabSpace = utfTo<std::string>(TAB_SPACE);
@@ -104,7 +132,7 @@ std::string generateLogHeaderTxt(const ProcessSummary& s, const ErrorLog& log, i
 
 std::string generateLogFooterTxt(const std::wstring& logFilePath /*optional*/, int logItemsTotal, int logItemsMax) //throw FileError
 {
-    const ComputerModel cm = getComputerModel(); //throw FileError
+    const std::wstring machDescr = getMachineDescription(); //throw FileError
 
     std::string output;
     if (logItemsTotal > logItemsMax)
@@ -113,10 +141,8 @@ std::string generateLogFooterTxt(const std::wstring& logFilePath /*optional*/, i
 
     output += std::string(SEPARATION_LINE_LEN, '_') + '\n' +
 
-              utfTo<std::string>(getOsDescription() + /*throw FileError*/ +
-                                 L" - " + utfTo<std::wstring>(getUserDescription()) /*throw FileError*/ +
-                                 (!cm.model .empty() ? L" - " + cm.model  : L"") +
-                                 (!cm.vendor.empty() ? L" - " + cm.vendor : L"")) + '\n';
+              utfTo<std::string>(getOsDescription() + L" - " + getUserDescription() /*throw FileError*/ +
+                                 (!machDescr.empty() ? L" - " + machDescr : L"")) + '\n';
     if (!logFilePath.empty())
         output += utfTo<std::string>(_("Log file:") + L' ' + logFilePath) + '\n';
 
@@ -173,7 +199,7 @@ std::string formatMessageHtml(const LogEntry& entry)
     return R"(		<tr>
             <td valign="top">)" + htmlTxt(formatTime(formatTimeTag, getLocalTime(entry.time))) + R"(</td>
             <td valign="top"><img src="https://freefilesync.org/images/log/)" + typeImage + R"(" width="16" height="16" alt=")" + typeLabel + R"(:"></td>
-            <td>)" + htmlTxt(makeStringView(entry.message.begin(), entry.message.end())) + R"(</td>
+            <td>)" + htmlTxt(std::string_view(entry.message.begin(), entry.message.end())) + R"(</td>
         </tr>
 )";
 }
@@ -336,7 +362,7 @@ std::string generateLogHeaderHtml(const ProcessSummary& s, const ErrorLog& log,
 std::string generateLogFooterHtml(const std::wstring& logFilePath /*optional*/, int logItemsTotal, int logItemsMax) //throw FileError
 {
     const std::string osImage = "os-linux.png";
-    const ComputerModel cm = getComputerModel(); //throw FileError
+    const std::wstring machDescr = getMachineDescription(); //throw FileError
 
     std::string output = R"(	</table>
 )";
@@ -350,10 +376,9 @@ std::string generateLogFooterHtml(const std::wstring& logFilePath /*optional*/,
     <div style="border-bottom:1px solid #AAA; margin:5px 0;"></div>
     <div style="font-size:smaller;">
         <img src="https://freefilesync.org/images/log/)" + osImage + R"(" width="24" height="24" alt="" style="vertical-align:middle;">
-        <span style="vertical-align:middle;">)" + htmlTxt(getOsDescription()) + /*throw FileError*/ + 
+        <span style="vertical-align:middle;">)" + htmlTxt(getOsDescription()) + 
             " &ndash; " + htmlTxt(getUserDescription()) /*throw FileError*/ + 
-            (!cm.model .empty() ? " &ndash; " + htmlTxt(cm.model ) : "") +
-            (!cm.vendor.empty() ? " &ndash; " + htmlTxt(cm.vendor) : "") + R"(</span>
+                          (!machDescr.empty() ? " &ndash; " + htmlTxt(machDescr) : "") + R"(</span>
     </div>)";
 
     if (!logFilePath.empty())
@@ -500,7 +525,7 @@ std::vector<LogFileInfo> getLogFiles(const AbstractPath& logFolderPath) //throw
                 isdigit(itemPhrase.end()[-2]) &&
                 isdigit(itemPhrase.end()[-1]))
             {
-                const TimeComp tc = parseTime(Zstr("%Y-%m-%d %H%M%S"), makeStringView(itemPhrase.end() - TIME_STAMP_LENGTH, 17)); //returns TimeComp() on error
+                const TimeComp tc = parseTime(Zstr("%Y-%m-%d %H%M%S"), ZstringView(&itemPhrase.end()[-TIME_STAMP_LENGTH], 17)); //returns TimeComp() on error
                 if (const auto [localTime, timeValid] = localToTimeT(tc);
                     timeValid)
                 {
