@@ -70,35 +70,27 @@ void StatusHandlerTemporaryPanel::showStatsPanel()
                 //case wxAUI_DOCK_CENTRE:
         }
 
-        wxAuiPaneInfoArray& paneArray = mainDlg_.auiMgr_.GetAllPanes();
-
         const bool statusRowTaken = [&]
         {
-            for (size_t i = 0; i < paneArray.size(); ++i)
-            {
-                const wxAuiPaneInfo& paneInfo = paneArray[i];
+            for (wxAuiPaneInfo& paneInfo : mainDlg_.auiMgr_.GetAllPanes())
                 //doesn't matter if paneInfo.IsShown() or not! => move down in either case!
                 if (&paneInfo != &statusPanel &&
                     paneInfo.dock_layer     == statusPanel.dock_layer &&
                     paneInfo.dock_direction == statusPanel.dock_direction &&
                     paneInfo.dock_row       == statusPanel.dock_row)
                     return true;
-            }
+
             return false;
         }();
 
         //move all rows that are in the way one step further
         if (statusRowTaken)
-            for (size_t i = 0; i < paneArray.size(); ++i)
-            {
-                wxAuiPaneInfo& paneInfo = paneArray[i];
-
+            for (wxAuiPaneInfo& paneInfo : mainDlg_.auiMgr_.GetAllPanes())
                 if (&paneInfo != &statusPanel &&
                     paneInfo.dock_layer     == statusPanel.dock_layer &&
                     paneInfo.dock_direction == statusPanel.dock_direction &&
                     paneInfo.dock_row       >= statusPanel.dock_row)
                     ++paneInfo.dock_row;
-            }
         //------------------------------------------------------------------
 
         statusPanel.Show();
@@ -116,11 +108,13 @@ StatusHandlerTemporaryPanel::~StatusHandlerTemporaryPanel()
     //Workaround wxAuiManager crash when starting panel resizing during comparison and holding button until after comparison has finished:
     //- unlike regular window resizing, wxAuiManager does not run a dedicated event loop while the mouse button is held
     //- wxAuiManager internally stores the panel index that is currently resized
-    //- our previous hiding of the compare status panel invalidates this index
+    //- our hiding of the compare status panel invalidates this index
     // => the next mouse move will have wxAuiManager crash => another fine piece of "wxQuality" code
     // => mitigate:
     wxMouseCaptureLostEvent dummy;
-    mainDlg_.auiMgr_.ProcessEvent(dummy); //should be no-op if no mouse buttons are pressed
+    mainDlg_.ProcessEvent(dummy); //trigger wxAuiManager::OnCaptureLost(); should be no-op if no mouse buttons are pressed
+    if (wxWindow::GetCapture() == &mainDlg_)
+        mainDlg_.ReleaseMouse();
 
     mainDlg_.auiMgr_.GetPane(mainDlg_.compareStatus_->getAsWindow()).Hide();
     mainDlg_.auiMgr_.Update();
@@ -193,11 +187,9 @@ void StatusHandlerTemporaryPanel::logMessage(const std::wstring& msg, MsgType ty
     {
         switch (type)
         {
-            //*INDENT-OFF*
             case MsgType::info:    return MSG_TYPE_INFO;
             case MsgType::warning: return MSG_TYPE_WARNING;
             case MsgType::error:   return MSG_TYPE_ERROR;
-            //*INDENT-ON*
         }
         assert(false);
         return MSG_TYPE_ERROR;
@@ -249,10 +241,10 @@ ProcessCallback::Response StatusHandlerTemporaryPanel::reportError(const ErrorIn
     if (errorInfo.retryNumber < autoRetryCount_)
     {
         logMsg(errorLog_, errorInfo.msg + L"\n-> " + _("Automatic retry"), MSG_TYPE_INFO, failTime);
-        delayAndCountDown(errorInfo.failTime + autoRetryDelay_,
+        delayAndCountDown(errorInfo.failTime + autoRetryDelay_ - std::chrono::steady_clock::now(),
                           [&, statusPrefix  = _("Automatic retry") +
                                               (errorInfo.retryNumber == 0 ? L"" : L' ' + formatNumber(errorInfo.retryNumber + 1)) + SPACED_DASH,
-                              statusPostfix = SPACED_DASH + _("Error") + L": " + replaceCpy(errorInfo.msg, L'\n', L' ')](const std::wstring& timeRemMsg)
+                           statusPostfix = SPACED_DASH + _("Error") + L": " + replaceCpy(errorInfo.msg, L'\n', L' ')](const std::wstring& timeRemMsg)
         { this->updateStatus(statusPrefix + timeRemMsg + statusPostfix); }); //throw CancelProcess
         return ProcessCallback::retry;
     }
@@ -400,7 +392,7 @@ StatusHandlerFloatingDialog::StatusHandlerFloatingDialog(wxFrame* parentDlg,
 
 StatusHandlerFloatingDialog::~StatusHandlerFloatingDialog()
 {
-    if (progressDlg_) //showResults() was not called!
+    if (progressDlg_) //prepareResult() was not called!
         std::abort();
 }
 
@@ -474,14 +466,14 @@ StatusHandlerFloatingDialog::DlgOptions StatusHandlerFloatingDialog::showResult(
                     assert(!endsWith(operationName, L"."));
                     auto notifyStatus = [&](const std::wstring& timeRemMsg) { updateStatus(operationName + L"... " + timeRemMsg); /*throw CancelProcess*/ };
 
-                    delayAndCountDown(std::chrono::steady_clock::now() + std::chrono::seconds(10), notifyStatus); //throw CancelProcess
+                    delayAndCountDown(std::chrono::seconds(10), notifyStatus); //throw CancelProcess
                 }
                 catch (CancelProcess&) { return false; }
 
             return true;
         };
 
-        switch (progressDlg_->getOptionPostSyncAction())
+        switch (progressDlg_->getAndFreezePostSyncAction())
         {
             case PostSyncAction::none:
                 autoClose = progressDlg_->getOptionAutoCloseDialog();
@@ -555,11 +547,9 @@ void StatusHandlerFloatingDialog::logMessage(const std::wstring& msg, MsgType ty
     {
         switch (type)
         {
-            //*INDENT-OFF*
             case MsgType::info:    return MSG_TYPE_INFO;
             case MsgType::warning: return MSG_TYPE_WARNING;
             case MsgType::error:   return MSG_TYPE_ERROR;
-            //*INDENT-ON*
         }
         assert(false);
         return MSG_TYPE_ERROR;
@@ -611,10 +601,10 @@ ProcessCallback::Response StatusHandlerFloatingDialog::reportError(const ErrorIn
     if (errorInfo.retryNumber < autoRetryCount_)
     {
         logMsg(errorLog_.ref(), errorInfo.msg + L"\n-> " + _("Automatic retry"), MSG_TYPE_INFO, failTime);
-        delayAndCountDown(errorInfo.failTime + autoRetryDelay_,
+        delayAndCountDown(errorInfo.failTime + autoRetryDelay_ - std::chrono::steady_clock::now(),
                           [&, statusPrefix  = _("Automatic retry") +
                                               (errorInfo.retryNumber == 0 ? L"" : L' ' + formatNumber(errorInfo.retryNumber + 1)) + SPACED_DASH,
-                              statusPostfix = SPACED_DASH + _("Error") + L": " + replaceCpy(errorInfo.msg, L'\n', L' ')](const std::wstring& timeRemMsg)
+                           statusPostfix = SPACED_DASH + _("Error") + L": " + replaceCpy(errorInfo.msg, L'\n', L' ')](const std::wstring& timeRemMsg)
         { this->updateStatus(statusPrefix + timeRemMsg + statusPostfix); }); //throw CancelProcess
         return ProcessCallback::retry;
     }
