@@ -9,7 +9,6 @@
 
 #include <functional>
 #include <zen/error_log.h>
-//#include <wx/frame.h>
 #include "wx+/window_tools.h"
 #include "../status_handler.h"
 
@@ -84,7 +83,7 @@ struct SyncProgressDialog
     //allow changing a few options dynamically during sync
     virtual bool getOptionIgnoreErrors()           const = 0;
     virtual void setOptionIgnoreErrors(bool ignoreError) = 0;
-    virtual PostSyncAction getOptionPostSyncAction() const = 0;
+    virtual PostSyncAction getAndFreezePostSyncAction() const = 0;
     virtual bool getOptionAutoCloseDialog() const = 0;
 
     virtual void timerSetStatus(bool active) = 0; //start/stop all internal timers!
