@@ -718,10 +718,9 @@ globalLogFolderPhrase_(globalLogFolderPhrase)
     selectFolderPairConfig(-1);
 
     GetSizer()->SetSizeHints(this); //~=Fit() + SetMinSize()
-#ifdef __WXGTK3__
     Show(); //GTK3 size calculation requires visible window: https://github.com/wxWidgets/wxWidgets/issues/16088
     //Hide(); -> avoids old position flash before Center() on GNOME but causes hang on KDE? https://freefilesync.org/forum/viewtopic.php?t=10103#p42404
-#endif
+
     Center(); //apply *after* dialog size change!
 
     //keep stable sizer height: change-based directions are taller than difference-based ones => init with SyncVariant::twoWay
