@@ -29,7 +29,10 @@ public:
                      long style                   = 0,
                      const wxValidator& validator = wxDefaultValidator,
                      const wxString& name         = wxASCII_STR(wxButtonNameStr)) :
-        wxBitmapButton(parent, id, wxNullBitmap, pos, size, style, validator, name)
+        wxBitmapButton(parent, id,
+                       //(FreeFileSync_x86_64:77379): Gtk-CRITICAL **: 11:04:31.752: IA__gtk_widget_modify_style: assertion 'GTK_IS_WIDGET (widget)' failed
+                       rectangleImage({1, 1}, *wxRED),
+    pos, size, style, validator, name)
     {
         SetLabel(label);
     }
@@ -68,7 +71,7 @@ void setBitmapTextLabel(wxBitmapButton& btn, const wxImage& img, const wxString&
                  stackImages(img, imgTxt, ImageStackLayout::horizontal, ImageStackAlignment::center, wxsizeToScreen(gap)) :
                  stackImages(imgTxt, img, ImageStackLayout::horizontal, ImageStackAlignment::center, wxsizeToScreen(gap));
 
-    //SetMinSize() instead of SetSize() is needed here for wxWindows layout determination to work correctly
+    //SetMinSize() instead of SetSize() is needed here for wxWidgets layout determination to work correctly
     btn.SetMinSize({screenToWxsize(imgTxt.GetWidth()) + 2 * border,
                     std::max(screenToWxsize(imgTxt.GetHeight()) + 2 * border, getDefaultButtonHeight())});
 
