@@ -15,8 +15,7 @@ namespace zen
 //COM needs to be initialized before calling any of these functions! CoInitializeEx/CoUninitialize
 
 Zstring getLoginUser(); //throw FileError
-Zstring getUserDescription();//throw FileError
-
+Zstring getHostName(); //throw FileError
 
 struct ComputerModel
 {
@@ -27,7 +26,7 @@ ComputerModel getComputerModel(); //throw FileError
 
 
 
-std::wstring getOsDescription(); //throw FileError
+std::wstring getOsDescription();
 
 
 Zstring getProcessPath(); //throw FileError
