@@ -12,7 +12,7 @@
 using namespace zen;
 
 
-OsVersionDetail zen::getOsVersionDetail() //throw SysError
+OsVersionDetail impl::getOsVersionRaw() //throw SysError
 {
     /* prefer lsb_release:             lsb_release      Distributor ID: Debian
          1. terser OS name                              Release:        8.11
@@ -81,21 +81,21 @@ OsVersionDetail zen::getOsVersionDetail() //throw SysError
 }
 
 
-OsVersion zen::getOsVersion()
+OsVersionDetail zen::getOsVersion()
 {
-    static const OsVersionDetail verDetail = []
+    static const OsVersionDetail verDetail = [] //another magic static
     {
         try
         {
-            return getOsVersionDetail(); //throw SysError
+            return impl::getOsVersionRaw(); //throw SysError
         }
-        catch (const SysError& e)
+        catch (const SysError& e) //errors are unexpected!
         {
-            logExtraError(_("Cannot get process information.") + L"\n\n" + e.toString());
-            return OsVersionDetail{}; //arrgh, it's a jungle out there: https://freefilesync.org/forum/viewtopic.php?t=7276
+            throw std::runtime_error(std::string(__FILE__) + '[' + numberTo<std::string>(__LINE__) + "] Failed to determine OS version." + "\n\n" +
+                                     utfTo<std::string>(e.toString()));
         }
     }();
-    return verDetail.version;
+    return verDetail;
 }
 
 
